@@ -1,17 +1,20 @@
-use std::sync::mpsc::Receiver;
 use std::thread::JoinHandle;
 
-use clap::{value_t, ArgMatches};
+use clap::ArgMatches;
 use config::{Config, ConfigError, Environment, File};
 use log::debug;
-use oura::framework::{
-    BootstrapResult, Event, FilterConfig, PartialBootstrapResult, SinkConfig, SourceConfig,
+use oura::pipelining::{
+    BootstrapResult, FilterProvider, PartialBootstrapResult, SinkProvider, SourceProvider,
+    StageReceiver,
 };
 use oura::sinks::terminal::Config as TerminalConfig;
 use oura::sources::n2c::Config as N2CConfig;
 use oura::sources::n2n::Config as N2NConfig;
 use serde_derive::Deserialize;
 
+#[cfg(feature = "webhook")]
+use oura::sinks::webhook::Config as WebhookConfig;
+
 #[cfg(feature = "kafkasink")]
 use oura::sinks::kafka::Config as KafkaConfig;
 
@@ -33,7 +36,7 @@ enum Source {
     N2N(N2NConfig),
 }
 
-impl SourceConfig for Source {
+impl SourceProvider for Source {
     fn bootstrap(&self) -> PartialBootstrapResult {
         match self {
             Source::N2C(c) => c.bootstrap(),
@@ -52,8 +55,8 @@ enum Filter {
     Fingerprint(FingerprintConfig),
 }
 
-impl FilterConfig for Filter {
-    fn bootstrap(&self, input: Receiver<Event>) -> PartialBootstrapResult {
+impl FilterProvider for Filter {
+    fn bootstrap(&self, input: StageReceiver) -> PartialBootstrapResult {
         match self {
             Filter::Noop(c) => c.bootstrap(input),
             Filter::Selection(c) => c.bootstrap(input),
@@ -69,6 +72,9 @@ impl FilterConfig for Filter {
 enum Sink {
     Terminal(TerminalConfig),
 
+    #[cfg(feature = "webhook")]
+    Webhook(WebhookConfig),
+
     #[cfg(feature = "kafkasink")]
     Kafka(KafkaConfig),
 
@@ -76,11 +82,14 @@ enum Sink {
     Elastic(ElasticConfig),
 }
 
-impl SinkConfig for Sink {
-    fn bootstrap(&self, input: Receiver<Event>) -> BootstrapResult {
+impl SinkProvider for Sink {
+    fn bootstrap(&self, input: StageReceiver) -> BootstrapResult {
         match self {
             Sink::Terminal(c) => c.bootstrap(input),
 
+            #[cfg(feature = "webhook")]
+            Sink::Webhook(c) => c.bootstrap(input),
+
             #[cfg(feature = "kafkasink")]
             Sink::Kafka(c) => c.bootstrap(input),
 
@@ -147,7 +156,7 @@ pub fn run(args: &ArgMatches) -> Result<(), Error> {
     env_logger::init();
 
     let explicit_config = match args.is_present("config") {
-        true => Some(value_t!(args, "config", String)?),
+        true => Some(args.value_of_t("config")?),
         false => None,
     };
 
