@@ -1,17 +1,19 @@
 //! A noop filter used as example and placeholder for other filters
 
-use std::{sync::mpsc::Receiver, thread};
+use std::thread;
 
 use serde_derive::Deserialize;
 
-use crate::framework::{Event, FilterConfig, PartialBootstrapResult};
+use crate::pipelining::{
+    new_inter_stage_channel, FilterProvider, PartialBootstrapResult, StageReceiver,
+};
 
 #[derive(Debug, Deserialize)]
 pub struct Config {}
 
-impl FilterConfig for Config {
-    fn bootstrap(&self, input: Receiver<Event>) -> PartialBootstrapResult {
-        let (output_tx, output_rx) = std::sync::mpsc::channel();
+impl FilterProvider for Config {
+    fn bootstrap(&self, input: StageReceiver) -> PartialBootstrapResult {
+        let (output_tx, output_rx) = new_inter_stage_channel(None);
 
         let handle = thread::spawn(move || loop {
             let msg = input.recv().expect("error receiving message");
