@@ -1,5 +1,3 @@
-use std::sync::mpsc::Receiver;
-
 use elasticsearch::{
     auth::Credentials as ESCredentials,
     cert::CertificateValidation,
@@ -12,7 +10,7 @@ use elasticsearch::{
 
 use serde_derive::Deserialize;
 
-use crate::framework::{BootstrapResult, Event, SinkConfig};
+use crate::pipelining::{BootstrapResult, SinkProvider, StageReceiver};
 
 use super::run::writer_loop;
 
@@ -34,16 +32,16 @@ impl From<&CredentialsConfig> for ESCredentials {
 
 #[derive(Default, Debug, Deserialize)]
 pub struct Config {
-    url: String,
-    index: String,
-    credentials: Option<CredentialsConfig>,
+    pub url: String,
+    pub index: String,
+    pub credentials: Option<CredentialsConfig>,
 
     #[serde(default)]
-    idempotency: bool,
+    pub idempotency: bool,
 }
 
-impl SinkConfig for Config {
-    fn bootstrap(&self, input: Receiver<Event>) -> BootstrapResult {
+impl SinkProvider for Config {
+    fn bootstrap(&self, input: StageReceiver) -> BootstrapResult {
         let pool = SingleNodeConnectionPool::new(Url::parse(&self.url)?);
         let mut transport =
             TransportBuilder::new(pool).cert_validation(CertificateValidation::None);
