@@ -1,9 +1,9 @@
-use std::{sync::mpsc::Receiver, time::Duration};
+use std::time::Duration;
 
 use kafka::{client::RequiredAcks, producer::Producer};
 use serde_derive::Deserialize;
 
-use crate::framework::{BootstrapResult, Event, SinkConfig};
+use crate::pipelining::{BootstrapResult, SinkProvider, StageReceiver};
 
 use super::run::producer_loop;
 
@@ -15,14 +15,14 @@ pub enum PartitionStrategy {
 
 #[derive(Default, Debug, Deserialize)]
 pub struct Config {
-    brokers: Vec<String>,
-    topic: String,
-    ack_timeout_secs: Option<u64>,
-    paritioning: Option<PartitionStrategy>,
+    pub brokers: Vec<String>,
+    pub topic: String,
+    pub ack_timeout_secs: Option<u64>,
+    pub paritioning: Option<PartitionStrategy>,
 }
 
-impl SinkConfig for Config {
-    fn bootstrap(&self, input: Receiver<Event>) -> BootstrapResult {
+impl SinkProvider for Config {
+    fn bootstrap(&self, input: StageReceiver) -> BootstrapResult {
         let mut builder = Producer::from_hosts(self.brokers.clone());
 
         if let Some(timeout) = &self.ack_timeout_secs {
