@@ -1,4 +1,6 @@
-use std::{net::TcpStream, ops::Deref, os::unix::net::UnixStream, sync::mpsc};
+#[cfg(target_family = "unix")]
+use std::os::unix::net::UnixStream;
+use std::{net::TcpStream, ops::Deref};
 
 use net2::TcpStreamExt;
 
@@ -13,14 +15,14 @@ use pallas::ouroboros::network::{
 use serde_derive::Deserialize;
 
 use crate::{
-    framework::{ChainWellKnownInfo, Error, EventWriter, PartialBootstrapResult, SourceConfig},
-    mapping::MapperConfig,
-    sources::{
-        common::{find_end_of_chain, AddressArg, BearerKind, MagicArg, PointArg},
-        n2n::{fetch_blocks_forever, observe_headers_forever},
-    },
+    mapper::{ChainWellKnownInfo, Config as MapperConfig, EventWriter},
+    pipelining::{new_inter_stage_channel, PartialBootstrapResult, SourceProvider},
+    sources::common::{find_end_of_chain, AddressArg, BearerKind, MagicArg, PointArg},
+    Error,
 };
 
+use super::run::{fetch_blocks_forever, observe_headers_forever};
+
 #[derive(Debug, Deserialize)]
 pub struct Config {
     pub address: AddressArg,
@@ -47,6 +49,7 @@ fn do_handshake(channel: &mut Channel, magic: u64) -> Result<(), Error> {
     }
 }
 
+#[cfg(target_family = "unix")]
 fn setup_unix_multiplexer(path: &str) -> Result<Multiplexer, Error> {
     let unix = UnixStream::connect(path)?;
 
@@ -61,12 +64,13 @@ fn setup_tcp_multiplexer(address: &str) -> Result<Multiplexer, Error> {
     Multiplexer::setup(tcp, &[0, 2, 3])
 }
 
-impl SourceConfig for Config {
+impl SourceProvider for Config {
     fn bootstrap(&self) -> PartialBootstrapResult {
-        let (output_tx, output_rx) = mpsc::channel();
+        let (output_tx, output_rx) = new_inter_stage_channel(None);
 
         let mut muxer = match self.address.0 {
             BearerKind::Tcp => setup_tcp_multiplexer(&self.address.1)?,
+            #[cfg(target_family = "unix")]
             BearerKind::Unix => setup_unix_multiplexer(&self.address.1)?,
         };
 
@@ -94,7 +98,7 @@ impl SourceConfig for Config {
 
         info!("starting from chain point: {:?}", &since);
 
-        let (headers_tx, headers_rx) = std::sync::mpsc::channel();
+        let (headers_tx, headers_rx) = std::sync::mpsc::sync_channel(100);
 
         let cs_writer = writer.clone();
         let cs_handle = std::thread::spawn(move || {
